use crate::model::Texture;
use serde::{Deserialize, Serialize};
use std::fs;
use std::io;
use std::path::Path;

#[derive(Deserialize, Serialize)]
struct CollectionFile {
    textures: Vec<Texture>,
}

pub fn load_collection_file(path: &Path) -> io::Result<Vec<Texture>> {
    match fs::File::open(path) {
        Ok(file) => {
            let buf_reader = io::BufReader::new(file);

            let collection: CollectionFile = serde_json::from_reader(buf_reader)?;
            Ok(collection.textures)
        }
        Err(e) => {
            if e.kind() == io::ErrorKind::NotFound {
                // File has not been created yet.
                Ok(Vec::new())
            } else {
                Err(e)
            }
        }
    }
}

pub fn store_collection_file(path: &Path, content: &Vec<Texture>) -> io::Result<()> {
    let collection_file = CollectionFile {
        textures: content.clone(),
    };
    let file = fs::File::create(path)?;
    serde_json::to_writer(file, &collection_file)?;
    Ok(())
}
